@@ -846,18 +846,18 @@ double constructReg::mdlAux(constructRegNode *Node)
          return mdlAux(Node->left) + mdlAux(Node->right) ;
 
       case cnCONTattribute: // summing and multiplying
-         return log2((double)(gRT->noNumeric-1)) ;
+         return mlog2((double)(gRT->noNumeric-1)) ;
       
       case cnCONTattrValue:
       {
         double intValue = gRT->valueInterval[Node->attrIdx]/gRT->opt->mdlErrorPrecision ;
         if (intValue < 1.0)
           intValue = 1.0 ;
-        return  log2((double)gRT->noAttr) + 2.0*log2((double)intValue) ;
+        return  mlog2((double)gRT->noAttr) + 2.0*mlog2((double)intValue) ;
       }
       case  cnDISCattrValue:
-        return log2((double)gRT->noAttr) +
-               log2((double)gRT->AttrDesc[gRT->DiscIdx[Node->attrIdx]].NoValues) ;
+        return mlog2((double)gRT->noAttr) +
+               mlog2((double)gRT->AttrDesc[gRT->DiscIdx[Node->attrIdx]].NoValues) ;
 
       case cnDISCattribute:
       default: 
@@ -877,11 +877,11 @@ double constructReg::mdlAux(constructRegNode *Node)
 // *********************************************************************
 double constructReg::mdlConstructCode() 
 {
-   double code = log2((double)no1bits(gRT->opt->constructionMode)) ;
+   double code = mlog2((double)no1bits(gRT->opt->constructionMode)) ;
    switch (compositionType)
    {
      case cSINGLEattribute:
-          code += log2((double)gRT->noAttr) ;
+          code += mlog2((double)gRT->noAttr) ;
           if (countType == aDISCRETE)
           {
  //           marray<double> Multinom(2, 0.0) ;  
@@ -898,17 +898,17 @@ double constructReg::mdlConstructCode()
             double intValue = gRT->valueInterval[root->attrIdx]/gRT->opt->mdlModelPrecision ;
             if (intValue < 1.0)
               intValue = 1.0 ;
-            code += log2(intValue) ;
+            code += mlog2(intValue) ;
           }
           break ;       
      case cCONJUNCTION:
-         code += log2((double)gRT->opt->maxConstructSize) ;
+         code += mlog2((double)gRT->opt->maxConstructSize) ;
          code += mdlAux() ;       
          break ;
     
      case cSUM:
      case cPRODUCT:
-         {  code += log2((double)gRT->opt->maxConstructSize) ;
+         {  code += mlog2((double)gRT->opt->maxConstructSize) ;
             // selection of the attributes       
             marray<double> Multinom(2, 0.0) ;  
             Multinom[0] = degreesOfFreedom() ;
